@@ -3,6 +3,8 @@
 #include <cstring>
 #include<cmath>
 
+#include "c212_Rdefines.h"
+
 #include <R.h>
 #include <Rmath.h>
 #include <R_ext/Print.h>
@@ -13,7 +15,7 @@
 
 using namespace std;
 
-static const char *rcsId = "$Id: c2121a_poisson_mc_hier2_lev0.cpp,v 1.7 2018/10/03 15:40:28 clb13102 Exp clb13102 $";
+//static const char *rcsId = "$Id: c2121a_poisson_mc_hier2_lev0.cpp,v 1.7 2018/10/03 15:40:28 clb13102 Exp clb13102 $";
 
 const char* c2121a_poisson_mc_hier2_lev0::sColType = "type";
 const char* c2121a_poisson_mc_hier2_lev0::sColVariable = "variable";
@@ -520,7 +522,7 @@ void c2121a_poisson_mc_hier2_lev0::initSimParams(SEXP sSim_Params)
 
 	int len = Rf_length(sSim_Params);
 
-	if (len && isNewList(sSim_Params)) {
+	if (len && Rf_isNewList(sSim_Params)) {
 
 		SEXP sVariables = R_NilValue;
 		SEXP sParams = R_NilValue;
@@ -531,7 +533,7 @@ void c2121a_poisson_mc_hier2_lev0::initSimParams(SEXP sSim_Params)
 		//SEXP sIntervals = R_NilValue;
 		SEXP sI_index = R_NilValue;
 
-		SEXP names = getAttrib(sSim_Params, R_NamesSymbol);
+		SEXP names = Rf_getAttrib(sSim_Params, R_NamesSymbol);
 
 		for (i = 0; i < len; i++) {
 			if (strcmp(sColValue, CHAR(STRING_ELT(names, i))) == 0) {
@@ -676,8 +678,8 @@ void c2121a_poisson_mc_hier2_lev0::initMonitor(SEXP sMonitor)
     SEXP sVariables = R_NilValue;
     SEXP sValues = R_NilValue;
 
-    if (len > 0 && isNewList(sMonitor)) {
-        SEXP names = getAttrib(sMonitor, R_NamesSymbol);
+    if (len > 0 && Rf_isNewList(sMonitor)) {
+        SEXP names = Rf_getAttrib(sMonitor, R_NamesSymbol);
 
         int i = 0;
 
@@ -1833,7 +1835,7 @@ SEXP c2121a_poisson_mc_hier2_lev0::getL1Samples(double***** &data)
 	SEXP samples = R_NilValue;
 	SEXP dim = R_NilValue;
 
-	PROTECT(samples = allocVector(REALSXP, gChains * gNumIntervals * gMaxBs * gMaxAEs * (gIter - gBurnin)));
+	PROTECT(samples = Rf_allocVector(REALSXP, gChains * gNumIntervals * gMaxBs * gMaxAEs * (gIter - gBurnin)));
 
 	int i = 0;
 	int c = 0;
@@ -1869,7 +1871,7 @@ SEXP c2121a_poisson_mc_hier2_lev0::getL1Samples(double***** &data)
 	free(data);
 	data = NULL;
 
-	PROTECT(dim = allocVector(INTSXP, 5));
+	PROTECT(dim = Rf_allocVector(INTSXP, 5));
 
 	INTEGER(dim)[0] = (gIter - gBurnin);
 	INTEGER(dim)[1] = gMaxAEs;
@@ -1877,7 +1879,7 @@ SEXP c2121a_poisson_mc_hier2_lev0::getL1Samples(double***** &data)
 	INTEGER(dim)[3] = gNumIntervals;
 	INTEGER(dim)[4] = gChains;
 
-	setAttrib(samples, R_DimSymbol, dim);
+	Rf_setAttrib(samples, R_DimSymbol, dim);
 
 	UNPROTECT(2);
 
@@ -1889,7 +1891,7 @@ SEXP c2121a_poisson_mc_hier2_lev0::getL2Samples(double**** &data)
 	SEXP samples = R_NilValue;
 	SEXP dim = R_NilValue;
 
-	PROTECT(samples = allocVector(REALSXP, gChains * gNumIntervals * gMaxBs * (gIter - gBurnin)));
+	PROTECT(samples = Rf_allocVector(REALSXP, gChains * gNumIntervals * gMaxBs * (gIter - gBurnin)));
 
 	int i = 0;
 	int c = 0;
@@ -1915,14 +1917,14 @@ SEXP c2121a_poisson_mc_hier2_lev0::getL2Samples(double**** &data)
 	free(data);
 	data = NULL;
 
-	PROTECT(dim = allocVector(INTSXP, 4));
+	PROTECT(dim = Rf_allocVector(INTSXP, 4));
 
 	INTEGER(dim)[0] = (gIter - gBurnin);
 	INTEGER(dim)[1] = gMaxBs;
 	INTEGER(dim)[2] = gNumIntervals;
 	INTEGER(dim)[3] = gChains;
 
-	setAttrib(samples, R_DimSymbol, dim);
+	Rf_setAttrib(samples, R_DimSymbol, dim);
 
 	UNPROTECT(2);
 
@@ -1988,7 +1990,7 @@ SEXP c2121a_poisson_mc_hier2_lev0::getL1Accept(int**** &data)
 	SEXP acc = R_NilValue;
 	SEXP dim = R_NilValue;
 
-   PROTECT(acc = allocVector(INTSXP, gChains * gNumIntervals * gMaxBs * gMaxAEs));
+   PROTECT(acc = Rf_allocVector(INTSXP, gChains * gNumIntervals * gMaxBs * gMaxAEs));
 
 	int i = 0;
 	int c = 0;
@@ -2013,14 +2015,14 @@ SEXP c2121a_poisson_mc_hier2_lev0::getL1Accept(int**** &data)
 	free(data);
 	data = NULL;
 
-	PROTECT(dim = allocVector(INTSXP, 4));
+	PROTECT(dim = Rf_allocVector(INTSXP, 4));
 
 	INTEGER(dim)[0] = gMaxAEs;
 	INTEGER(dim)[1] = gMaxBs;
 	INTEGER(dim)[2] = gNumIntervals;
 	INTEGER(dim)[3] = gChains;
 
-	setAttrib(acc, R_DimSymbol, dim);
+	Rf_setAttrib(acc, R_DimSymbol, dim);
 
 	UNPROTECT(2);
 
