@@ -4,6 +4,8 @@
 #include <cstring>
 #include<cmath>
 
+#include "c212_Rdefines.h"
+
 #include <R.h>
 #include <Rmath.h>
 #include <R_ext/Print.h>
@@ -16,7 +18,7 @@
 
 using namespace std;
 
-static const char *rcsId = "$Id: c212BB_poisson_mc_hier2_lev0.cpp,v 1.9 2018/10/03 15:40:28 clb13102 Exp clb13102 $";
+//static const char *rcsId = "$Id: c212BB_poisson_mc_hier2_lev0.cpp,v 1.9 2018/10/03 15:40:28 clb13102 Exp clb13102 $";
 
 const char* c212BB_poisson_mc_hier2_lev0::sMonitor_pi = "pi";
 
@@ -129,9 +131,9 @@ void c212BB_poisson_mc_hier2_lev0::initGlobalSimParams(SEXP sSim_Type, SEXP sGlo
 		gSimType = eSim_Type_SLICE;
 	}
 
-    if (len > 0 && isNewList(sGlobal_Sim_Params)) {
+    if (len > 0 && Rf_isNewList(sGlobal_Sim_Params)) {
 
-        SEXP names = getAttrib(sGlobal_Sim_Params, R_NamesSymbol);
+        SEXP names = Rf_getAttrib(sGlobal_Sim_Params, R_NamesSymbol);
 
         int i = 0;
 
@@ -197,9 +199,9 @@ void c212BB_poisson_mc_hier2_lev0::initPMWeights(SEXP pm_weights)
 	SEXP sB = R_NilValue;
 	SEXP sj = R_NilValue;
 
-	if (len && isNewList(pm_weights)) {
+	if (len && Rf_isNewList(pm_weights)) {
 
-		SEXP names = getAttrib(pm_weights, R_NamesSymbol);
+		SEXP names = Rf_getAttrib(pm_weights, R_NamesSymbol);
 
 		for (i = 0; i < len; i++) {
 			if (strcmp(sColPMweight, CHAR(STRING_ELT(names, i))) == 0) {
@@ -268,7 +270,7 @@ void c212BB_poisson_mc_hier2_lev0::initSimParams(SEXP sSim_Params)
 
 	int len = Rf_length(sSim_Params);
 
-	if (len && isNewList(sSim_Params)) {
+	if (len && Rf_isNewList(sSim_Params)) {
 
 		SEXP sVariables = R_NilValue;
 		SEXP sParams = R_NilValue;
@@ -279,7 +281,7 @@ void c212BB_poisson_mc_hier2_lev0::initSimParams(SEXP sSim_Params)
 		//SEXP sIntervals = R_NilValue;
 		SEXP sI_index = R_NilValue;
 
-		SEXP names = getAttrib(sSim_Params, R_NamesSymbol);
+		SEXP names = Rf_getAttrib(sSim_Params, R_NamesSymbol);
 
 		for (i = 0; i < len; i++) {
 			if (strcmp(sColValue, CHAR(STRING_ELT(names, i))) == 0) {
@@ -659,9 +661,9 @@ void c212BB_poisson_mc_hier2_lev0::initMonitor(SEXP sMonitor)
     SEXP sVariables = R_NilValue;
     SEXP sValues = R_NilValue;
 
-    if (len > 0 && isNewList(sMonitor)) {
+    if (len > 0 && Rf_isNewList(sMonitor)) {
 
-        SEXP names = getAttrib(sMonitor, R_NamesSymbol);
+        SEXP names = Rf_getAttrib(sMonitor, R_NamesSymbol);
 
         int i = 0;
 
