@@ -4,6 +4,8 @@
 #include<cstring>
 #include<cmath>
 
+#include "c212_Rdefines.h"
+
 #include <R.h>
 #include <Rmath.h>
 #include <R_ext/Print.h>
@@ -19,7 +21,7 @@
 
 using namespace std;
 
-static const char *rcsId = "$Id: c212BB_poisson_mc_hier3_lev1.cpp,v 1.14 2018/10/03 15:40:28 clb13102 Exp clb13102 $";
+//static const char *rcsId = "$Id: c212BB_poisson_mc_hier3_lev1.cpp,v 1.14 2018/10/03 15:40:28 clb13102 Exp clb13102 $";
 
 c212BB_poisson_mc_hier3_lev1::c212BB_poisson_mc_hier3_lev1()
 {
@@ -1421,7 +1423,7 @@ SEXP c212BB_poisson_mc_hier3_lev1::getL2Samples(double*** &data)
 	SEXP samples = R_NilValue;
 	SEXP dim = R_NilValue;
 
-	PROTECT(samples = allocVector(REALSXP, gChains * gMaxBs * (gIter - gBurnin)));
+	PROTECT(samples = Rf_allocVector(REALSXP, gChains * gMaxBs * (gIter - gBurnin)));
 
 	int i = 0;
 	int c = 0;
@@ -1442,13 +1444,13 @@ SEXP c212BB_poisson_mc_hier3_lev1::getL2Samples(double*** &data)
 	free(data);
 	data = NULL;
 
-	PROTECT(dim = allocVector(INTSXP, 3));
+	PROTECT(dim = Rf_allocVector(INTSXP, 3));
 
 	INTEGER(dim)[0] = (gIter - gBurnin);
 	INTEGER(dim)[1] = gMaxBs;
 	INTEGER(dim)[2] = gChains;
 
-	setAttrib(samples, R_DimSymbol, dim);
+	Rf_setAttrib(samples, R_DimSymbol, dim);
 
 	UNPROTECT(2);
 
