@@ -4,6 +4,8 @@
 #include<cstring>
 #include<cmath>
 
+#include "c212_Rdefines.h"
+
 #include <R.h>
 #include <Rmath.h>
 #include <R_ext/Print.h>
@@ -18,7 +20,7 @@
 
 using namespace std;
 
-static const char *rcsId = "$Id: c212BB_poisson_mc_hier3_lev2.cpp,v 1.17 2018/10/03 15:40:27 clb13102 Exp clb13102 $";
+//static const char *rcsId = "$Id: c212BB_poisson_mc_hier3_lev2.cpp,v 1.17 2018/10/03 15:40:27 clb13102 Exp clb13102 $";
 
 c212BB_poisson_mc_hier3_lev2::c212BB_poisson_mc_hier3_lev2()
 {
@@ -1115,7 +1117,7 @@ SEXP c212BB_poisson_mc_hier3_lev2::getL3Samples(double** &data)
 	SEXP samples = R_NilValue;
 	SEXP dim = R_NilValue;
 
-	PROTECT(samples = allocVector(REALSXP, gChains * (gIter - gBurnin)));
+	PROTECT(samples = Rf_allocVector(REALSXP, gChains * (gIter - gBurnin)));
 
 	int i = 0;
 	int c = 0;
@@ -1129,12 +1131,12 @@ SEXP c212BB_poisson_mc_hier3_lev2::getL3Samples(double** &data)
 	free(data);
 	data = NULL;
 
-	PROTECT(dim = allocVector(INTSXP, 2));
+	PROTECT(dim = Rf_allocVector(INTSXP, 2));
 
 	INTEGER(dim)[0] = (gIter - gBurnin);
 	INTEGER(dim)[1] = gChains;
 
-	setAttrib(samples, R_DimSymbol, dim);
+	Rf_setAttrib(samples, R_DimSymbol, dim);
 
 	UNPROTECT(2);
 
@@ -1200,16 +1202,16 @@ SEXP c212BB_poisson_mc_hier3_lev2::getL3Accept(int* &data)
 	SEXP acc = R_NilValue;
 	SEXP dim = R_NilValue;
 
-	PROTECT(acc = allocVector(INTSXP, gChains));
+	PROTECT(acc = Rf_allocVector(INTSXP, gChains));
 	memcpy(INTEGER(acc), data, gChains*sizeof(int));
 
 	free(data);
 	data = NULL;
 
-	PROTECT(dim = allocVector(INTSXP, 1));
+	PROTECT(dim = Rf_allocVector(INTSXP, 1));
 
 	INTEGER(dim)[0] = gChains;
-	setAttrib(acc, R_DimSymbol, dim);
+	Rf_setAttrib(acc, R_DimSymbol, dim);
 
 	UNPROTECT(2);
 
